@@ -5,7 +5,7 @@ import doctest
 import logging
 import os
 import pathlib
-from typing import Any, Generator, Optional, Union
+from typing import Any, Generator, Union
 
 from typing_extensions import Literal
 from backports.cached_property import cached_property
@@ -84,6 +84,11 @@ class Session:
     '576323'
 
     """
+    def __lt__(self, other: Session) -> bool:
+        return self.date < other.date
+
+    def __repr__(self) -> str:
+        return f'{__class__.__name__}({self.folder!r})'
 
     def __init__(self, path: PathLike):
 
@@ -138,7 +143,7 @@ class Session:
         return date
 
     @property
-    def is_ecephys_session(self) -> Optional[bool]:
+    def is_ecephys_session(self) -> bool | None:
         """False if behavior session, None if unsure."""
         if not self.lims:
             return None
@@ -150,7 +155,7 @@ class Session:
         return NPEXP_ROOT / self.folder
 
     @property
-    def lims_path(self) -> Optional[pathlib.Path]:
+    def lims_path(self) -> pathlib.Path | None:
         """get lims id from path/str and lookup the corresponding directory in lims"""
         if not hasattr(self, "_lims_path"):
             path: str = self.lims.get("storage_directory", "")
@@ -164,11 +169,21 @@ class Session:
         return self._lims_path
 
     @property
-    def project(self) -> Optional[str]:
+    def qc_path(self) -> pathlib.Path:
+        "Expected default path, or alternative if one exists"
+        return self.qc_paths[0] if self.qc_paths else QC_PATHS[0] / self.folder
+    
+    @cached_property
+    def qc_paths(self) -> list[pathlib.Path]:
+        "Any QC folders that exist"
+        return [path / self.folder for path in QC_PATHS if (path / self.folder).exists()]    
+    
+    @property
+    def project(self) -> str | None:
         return self.lims.get("project", {}).get("name", None)
 
     @cached_property
-    def lims_data_getter(self) -> Optional[dg.lims_data_getter]:
+    def lims_data_getter(self) -> dg.dat | None:
         try:
             return dg.lims_data_getter(self.id)
         except ConnectionError:
@@ -178,7 +193,7 @@ class Session:
             raise
 
     @property
-    def data_dict(self) -> Optional[dict]:
+    def data_dict(self) -> dict | None:
         if not hasattr(self, "_data_dict"):
             data_getter = self.lims_data_getter
             if not data_getter:
@@ -189,7 +204,7 @@ class Session:
         return self._data_dict
 
     @property
-    def mtrain(self) -> Optional[dict]:
+    def mtrain(self) -> dict | None:
         """Info from MTrain on the last behavior session for the mouse on the experiment day"""
         if not hasattr(self, "_mtrain"):
             if not is_connected("mtrain"):
