@@ -63,11 +63,7 @@ def is_valid_session_id(session_id: int | str) -> bool:
     >>> is_valid_session_id('abcdefg')
     False
     """
-    try:
-        session = lims_data_getter(str(session_id))
-    except:
-        return False
-    return bool(session.data_dict) if hasattr(session, "data_dict") else False
+    return bool(SessionInfo(str(session_id)))
 
 
 def lims_session_id(path: PathLike) -> str | None:
@@ -130,7 +126,7 @@ def folder_from_lims_id(path: PathLike) -> str | None:
     )
 
 
-def folder_from_lims_id(path: PathLike) -> Optional[str]:
+def folder_from_lims_id(path: PathLike) -> str | None:
     """
     Get the session folder string ([lims-id]_[mouse-id]_[date]) from a string or path containing a possible lims id.
 
@@ -147,7 +143,7 @@ def folder_from_lims_id(path: PathLike) -> Optional[str]:
 
 
 @functools.lru_cache(maxsize=None)
-def lims_json_content(lims_id: int | str) -> Optional[dict]:
+def lims_json_content(lims_id: int | str) -> dict | None:
     if not is_valid_session_id(lims_id):
         raise ValueError(f"{lims_id} is not a valid lims session id")
     if not is_connected("lims2"):
